@@ -3,7 +3,7 @@
 #include <QDebug>
 #include <QDir>
 
-#include <MauiKit3/FileBrowsing/fmstatic.h>
+#include <MauiKit/FileBrowsing/fmstatic.h>
 
 #include "cmakeprojectmanager.h"
 #include "cmakeapi.h"
@@ -13,7 +13,6 @@
 ProjectManager::ProjectManager(QObject *parent) : QObject(parent)
   , m_projectManager(new CMakeProjectManager(this))
   , m_preferences(new ProjectPreferences(this))
-  ,m_active(false)
 {
     connect(this, &ProjectManager::projectUrlChanged, [this](QUrl)
     {
@@ -21,7 +20,6 @@ ProjectManager::ProjectManager(QObject *parent) : QObject(parent)
         if(!FMStatic::fileExists(m_projectUrl))
         {
             qWarning() << "CMake main file doesn't exists. Can not procced";
-            m_active = false;
             return;
         }
 
@@ -40,10 +38,6 @@ ProjectManager::ProjectManager(QObject *parent) : QObject(parent)
             m_projectLogo = m_projectPath.toString() +"/logo.png";
             emit this->projectLogoChanged(m_projectLogo);
         }
-
-        m_active = true;
-        emit activeChanged();
-
     });
 }
 
@@ -90,8 +84,3 @@ void ProjectManager::configure()
     //start the initial configuration of the project, like parsing and creating the needed files
     m_projectManager->init();
 }
-
-bool ProjectManager::active() const
-{
-    return m_active;
-}
