@@ -1,15 +1,13 @@
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QDate>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QIcon>
 
 #include <KI18n/KLocalizedString>
 
-#include <MauiKit3/Core/mauiapp.h>
-#include <MauiKit3/Terminal/moduleinfo.h>
-#include <MauiKit3/TextEditor/moduleinfo.h>
-#include <MauiKit3/FileBrowsing/moduleinfo.h>
+#include <MauiKit/Core/mauiapp.h>
 
 #include "controllers/processmanager.h"
 #include "controllers/projectmanager.h"
@@ -37,34 +35,20 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/img/strike.svg"));
 
-    KLocalizedString::setApplicationDomain("strike");
+    MauiApp::instance()->setIconName("qrc:/img/strike.svg");
 
-    KAboutData about(QStringLiteral("strike"),
-                     QStringLiteral("Strike"), 
-                     STRIKE_VERSION_STRING, 
-                     i18n("Build and run code."), 
-                     KAboutLicense::LGPL_V3,
-                     APP_COPYRIGHT_NOTICE, 
-                     QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KLocalizedString::setApplicationDomain("slike");
 
-    about.addAuthor(QStringLiteral("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
+    KAboutData about(QStringLiteral("strike"), "Strike", STRIKE_VERSION_STRING, i18n("Build and run code."), KAboutLicense::LGPL_V3,i18n("© 2021-%1 Camilo Higuita", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+
+    about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://slike.org");
     about.setProductName("slike/strike");
     about.setBugAddress("https://invent.kde.org/maui/strike/-/issues");
     about.setOrganizationDomain(STRIKE_URI);
     about.setProgramLogo(app.windowIcon());
 
-    const auto TData = MauiKitTerminal::aboutData();
-    about.addComponent(TData.name(), MauiKitTerminal::buildVersion(), TData.version(), TData.webAddress());
-
-    const auto FBData = MauiKitFileBrowsing::aboutData();
-    about.addComponent(FBData.name(), MauiKitFileBrowsing::buildVersion(), FBData.version(), FBData.webAddress());
-
-    const auto TEData = MauiKitTextEditor::aboutData();
-    about.addComponent(TEData.name(), MauiKitTextEditor::buildVersion(), TEData.version(), TEData.webAddress());
-
     KAboutData::setApplicationData(about);
-    MauiApp::instance()->setIconName("qrc:/img/strike.svg");
 
     QCommandLineParser parser;
 
@@ -89,8 +73,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     },
     Qt::QueuedConnection);
 
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-
     qmlRegisterSingletonInstance<Strike>(STRIKE_URI, 1, 0, "Strike", Strike::instance());
     qmlRegisterType<ProjectManager>(STRIKE_URI, 1, 0, "Project"); //entry point for the project
 
